
# #' @importFrom bazar is.empty
# #' @export
# #' 
# bazar::is_empty


#' @importFrom stats update
#' @export
#' 
stats::update


# #' @importFrom utils head
# #' @export
# #' 
# utils::head
